@@ -28,6 +28,7 @@
 
 #include <QLineEdit>
 #include <QLabel>
+#include <QSpinBox>
 #include <QFormLayout>
 #include <QHBoxLayout>
 #include <QComboBox>
@@ -51,7 +52,6 @@ SaveOptionsPage::SaveOptionsPage(QWidget *parent) :
     connect(mCopyPathToClipboard, &QCheckBox::toggled, this, &SaveOptionsPage::markDirty);
     mainLayout->addRow(QString(), mCopyPathToClipboard);
 
-
     mainLayout->addItem(new QSpacerItem(0, 18, QSizePolicy::Fixed, QSizePolicy::Fixed));
 
     // Compression quality slider and current value display
@@ -59,24 +59,24 @@ SaveOptionsPage::SaveOptionsPage(QWidget *parent) :
     QVBoxLayout *sliderVertLayout = new QVBoxLayout();
 
     // Current value
-    QLabel *qualityValue = new QLabel();
-    qualityValue->setNum(SpectacleConfig::instance()->compressionQuality());
-    qualityValue->setMinimumWidth(qualityValue->fontInfo().pointSize()*3);
+    QSpinBox *mQualitySpinner = new QSpinBox();
+    mQualitySpinner->setSuffix(QString::fromUtf8("%"));
+    mQualitySpinner->setRange(0, 100);
+    mQualitySpinner->setValue(SpectacleConfig::instance()->compressionQuality());
+    connect(mQualitySpinner, QOverload<int>::of(&QSpinBox::valueChanged), this, [=] (int value) {mQualitySlider->setValue(value);});
 
     // Slider
     mQualitySlider = new QSlider(Qt::Horizontal);
     mQualitySlider->setRange(0, 100);
-    mQualitySlider->setTickInterval(5);
     mQualitySlider->setSliderPosition(SpectacleConfig::instance()->compressionQuality());
-    mQualitySlider->setTickPosition(QSlider::TicksBelow);
     mQualitySlider->setTracking(true);
     connect(mQualitySlider, &QSlider::valueChanged, this, [=](int value) {
-        qualityValue->setNum(value);
+        mQualitySpinner->setValue(value);
         markDirty();
     });
 
     sliderHorizLayout->addWidget(mQualitySlider);
-    sliderHorizLayout->addWidget(qualityValue);
+    sliderHorizLayout->addWidget(mQualitySpinner);
 
     sliderVertLayout->addLayout(sliderHorizLayout);
 
@@ -136,7 +136,7 @@ SaveOptionsPage::SaveOptionsPage(QWidget *parent) :
         helpText += QStringLiteral("<a href=%1>%1</a>: %2<br>").arg(option.key(),
                                                                     option.value().toString());
     }
-    helpText += QStringLiteral("<a href='/'>/</a>: ") + i18n("To save to a sub-folder");
+    helpText += QLatin1String("<a href='/'>/</a>: ") + i18n("To save to a sub-folder");
     helpText += QStringLiteral("</blockquote>");
     QLabel *fmtHelpText = new QLabel(helpText, this);
     fmtHelpText->setWordWrap(true);
